/*
 * uart_common.h
 */

 #define    SHM_READER_KEY  210
 #define    SHM_SENDER_KEY  209

#define MaxTrFrames     (16)    // Send counts are written to 16 deep FIFO, burst mode
#define MaxPacketSize   (1024)  // Max size of each packet (bytes)
#define MaxMessageSize  (1024)  // Max size of each message (bytes)
#define DefaultBitrate  250000  // can be modified at runtime

enum msgtype_code       {CONTROL=1, POTMETER, XXX, DUMMY};
enum control_opcode     {RUN=10, PAUSE, STEP, STOP, ABORT};
enum pormeter_opcode    {JOG_SPEED=20, SPEED_OVER, SPINDLE_OVER};

typedef struct {
    unsigned short  len;
    unsigned char   msgtype;
} msg_head_t;

typedef struct {
    msg_head_t      h;
    unsigned char   opcode;
} control_msg_t;

typedef struct {
    msg_head_t      h;
    unsigned char   opcode;
    short int       value;
    short int       c[4];     // only for testing large messages
} potmeter_msg_t;

typedef struct {
    msg_head_t      h;
    unsigned char   opcode;
    short int       value;
    short int       c[6];
} xxx_msg_t;

typedef struct {
    msg_head_t      h;
} dummy_msg_t;

typedef union {
    control_msg_t   c;
    potmeter_msg_t  p;
    xxx_msg_t       x;
    dummy_msg_t     d;
} uart_msg_t;
